@@ -1,11 +1,11 @@
 # -- Project information -----------------------------------------------------
 
 project = "nxtomo"
-copyright = "2023, ESRF"
-author = "P.Paleo, H.Payno, A. Mirone, J.Lesaint"
+copyright = "2023-2025, ESRF"
+author = "P.Paleo, H.Payno, A. Mirone, J.Lesaint, P.-O. Autran"
 
 # The full version, including alpha/beta/rc tags
-release = "2.0"
+release = "3.0"
 version = release
 
 
@@ -24,8 +24,14 @@ extensions = [
     "sphinx.ext.autosummary",
     "nbsphinx",
     "sphinx_autodoc_typehints",
+    "myst_parser",
 ]
 
+source_suffix = {
+    ".rst": "restructuredtext",
+    ".md": "markdown",
+}
+
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
