@@ -25,13 +25,13 @@ from nxtomo.paths.nxtomo import LATEST_VERSION as LATEST_NXTOMO_VERSION
 from nxtomo.paths.nxtomo import get_paths as get_nexus_paths
 from nxtomo.utils import get_data, get_quantity
 
+_ureg = pint.get_application_registry()
+
 _logger = logging.getLogger(__name__)
 
 
 __all__ = ["NXtomo", "copy_nxtomo_file"]
 
-_ureg = pint.UnitRegistry()
-
 
 class NXtomo(NXobject):
     """
