@@ -49,7 +49,8 @@ _logger = logging.getLogger(__name__)
 
 __all__ = ["FOV", "ImageKey", "FieldOfView", "NXdetector", "NXdetectorWithUnit"]
 
-_ureg = pint.UnitRegistry()
+_ureg = pint.get_application_registry()
+
 _meter = _ureg.meter
 _second = _ureg.second
 
