@@ -16,13 +16,13 @@ from nxtomo.nxobject.nxsource import DefaultESRFSource, NXsource
 from nxtomo.paths.nxtomo import get_paths as get_nexus_paths
 from nxtomo.utils import get_data
 
+_ureg = pint.get_application_registry()
+
 _logger = logging.getLogger(__name__)
 
 __all__ = [
     "NXinstrument",
 ]
-
-_ureg = pint.UnitRegistry()
 _volt = _ureg.volt
 
 
