@@ -1,9 +1,7 @@
 """
-module for handling a `nxobject <https://manual.nexusformat.org/classes/base_classes/NXobject.html>`_
+Module for handling an `NXobject <https://manual.nexusformat.org/classes/base_classes/NXobject.html>`_.
 """
 
-from __future__ import annotations
-
 import logging
 import os
 
@@ -29,11 +27,11 @@ class NXobject:
 
     def __init__(self, node_name: str, parent=None) -> None:
         """
-        representation of `nexus NXobject <https://manual.nexusformat.org/classes/base_classes/NXobject.html>`_.
-        A monitor of incident beam data.
+        Representation of `NeXus NXobject <https://manual.nexusformat.org/classes/base_classes/NXobject.html>`_.
+        Base class for NXtomo objects.
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
+        :param node_name: name of the object in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
         """
         if not isinstance(node_name, str):
             raise TypeError(
@@ -54,7 +52,7 @@ class NXobject:
     @property
     def parent(self):  # -> NXobject | None:
         """
-        :class:`~nxtomo.nxobject.nxobject.NXobject` parent in the hierarchy
+        :class:`~nxtomo.nxobject.nxobject.NXobject` parent in the hierarchy.
         """
         return self._parent
 
@@ -62,18 +60,18 @@ class NXobject:
     def parent(self, parent) -> None:
         if not isinstance(parent, (type(None), NXobject)):
             raise TypeError(
-                f"parent is expected to be None or an instance of {NXobject}"
+                f"parent is expected to be None or an instance of {NXobject}. Got {type(parent)}"
             )
         self._parent = parent
 
     @property
     def is_root(self) -> bool:
-        """is this :class:`~nxtomo.nxobject.nxobject.NXobject` is the higher one"""
+        """Return True if this :class:`~nxtomo.nxobject.nxobject.NXobject` is the top-level object."""
         return self.parent is None
 
     @property
     def root_path(self) -> str:
-        """return path of the root :class:`~nxtomo.nxobject.nxobject.NXobject`"""
+        """Return the path of the root :class:`~nxtomo.nxobject.nxobject.NXobject`."""
         if self.is_root:
             return self.path
         else:
@@ -82,7 +80,7 @@ class NXobject:
     @property
     def path(self):
         """
-        path of the object in the nexus hierarchy
+        Path of the object in the NeXus hierarchy.
         """
 
         if self.parent is not None:
@@ -95,7 +93,7 @@ class NXobject:
 
     @property
     def node_name(self) -> str:
-        """name of the :class:`~nxtomo.nxobject.nxobject.NXobject` - in the nexus hierarchy"""
+        """Name of the :class:`~nxtomo.nxobject.nxobject.NXobject` in the NeXus hierarchy."""
         return self._node_name
 
     @node_name.setter
@@ -114,13 +112,14 @@ class NXobject:
         overwrite: bool = False,
     ) -> None:
         """
-        save NXtomo to disk.
+        Save the NXobject to disk.
 
-        :param file_path: hdf5 file
-        :param data_path: location to the NXobject. If not provided will be stored under node_name if provided (and valid)
-        :param nexus_path_version: Optional nexus version as float. If the saving must be done **not** using the latest version
-        :param overwrite: if the data_path in file_path is already existing overwrite it. Else raise will raise an error
+        :param file_path: HDF5 file path.
+        :param data_path: location of the NXobject. If not provided the node name is used (when valid).
+        :param nexus_path_version: optional NeXus version as float, when saving must use a non-latest version.
+        :param overwrite: if the data path already exists, overwrite it; otherwise, raise an error.
         """
+        file_path = os.path.abspath(file_path)
         if data_path == "/":
             _logger.warning(
                 "'data_path' set to '/' is now an invalid value. Please set 'data_path' to None if you want to store it under the NXobject name at root level, else provide data_path. Will ignore it."
@@ -150,6 +149,7 @@ class NXobject:
                         del h5f[entry_path]
                     else:
                         raise KeyError(f"{entry_path} already exists")
+
         if nexus_path_version is None:
             nexus_path_version = LATEST_NXTOMO_VERSION
 
@@ -171,6 +171,7 @@ class NXobject:
         for key, value in nx_dict.items():
             if key.startswith(dataset_to_postpone):
                 attributes[key] = value
+
         # clean attributes
         for key in attributes:
             del nx_dict[key]
@@ -190,10 +191,12 @@ class NXobject:
             # now handle nx_dict containing h5py.virtualSource or DataUrl
             # this cannot be handled from the nxdetector class because not aware about
             # the output file.
+
             for (
                 dataset_path,
                 v_sources_or_data_urls,
             ) in datasets_to_handle_in_postprocessing.items():
+
                 data_type = None
                 vs_shape = None
                 n_frames = 0
@@ -219,17 +222,17 @@ class NXobject:
                             f"Virtual sources have incoherent data types (found {data_type} and {vs.dtype})"
                         )
 
-                    if not len(vs.maxshape) == 3:
+                    if not len(vs.sel.mshape) == 3:
                         raise ValueError(
-                            f"Virtual sources are expected to be 3D. {len(vs.maxshape)} found"
+                            f"Virtual sources are expected to be 3D. {len(vs.sel.mshape)} found"
                         )
                     if vs_shape is None:
-                        vs_shape = vs.maxshape[1:]
-                    elif vs_shape != vs.maxshape[1:]:
+                        vs_shape = vs.sel.mshape[1:]
+                    elif vs_shape != vs.sel.mshape[1:]:
                         raise ValueError(
-                            f"Virtual sources are expected to have same frame dimensions. found {vs_shape} and {vs.maxshape[1:]}"
+                            f"Virtual sources are expected to have same frame dimensions. found {vs_shape} and {vs.sel.mshape[1:]}"
                         )
-                    n_frames += vs.maxshape[0]
+                    n_frames += vs.sel.mshape[0]
                     vs.path = to_target_rel_path(vs.path, file_path)
                     v_sources_to_handle_in_postprocessing.append(vs)
 
@@ -244,15 +247,14 @@ class NXobject:
                 # fill virtual dataset
                 loc_pointer = 0
                 for v_source in v_sources_to_handle_in_postprocessing:
-                    layout[loc_pointer : (loc_pointer + v_source.maxshape[0])] = (
+                    layout[loc_pointer : (loc_pointer + v_source.sel.mshape[0])] = (
                         v_source
                     )
-                    loc_pointer += v_source.maxshape[0]
+                    loc_pointer += v_source.sel.mshape[0]
 
                 with HDF5File(file_path, mode="a") as h5s:
-                    h5s.create_virtual_dataset(
-                        "/".join([entry_path, dataset_path]), layout
-                    )
+                    detector_data_path = "/".join([entry_path, dataset_path])
+                    h5s.create_virtual_dataset(detector_data_path, layout)
 
         # write attributes of dataset defined from a list of DataUrl or VirtualSource
         assert os.path.exists(file_path)
@@ -270,10 +272,10 @@ class NXobject:
         data_path: str | None = None,
     ) -> dict:
         """
-        convert the NXobject to an nx dict. Dictionary that we can dump to hdf5 file
+        Convert the NXobject to an NX dictionary suitable for dumping to an HDF5 file.
 
-        :param nexus_path_version: version of the nexus path version to use
-        :param data_path: can be provided to create some link in the file
+        :param nexus_path_version: NeXus path version to use.
+        :param data_path: optional data path used to build links in the file.
         """
         raise NotImplementedError("Base class")
 
@@ -282,7 +284,7 @@ class NXobject:
 
     @staticmethod
     def _get_virtual_sources(ddict) -> tuple:
-        """Return key / path containing a list or a tuple of h5py.VirtualSource"""
+        """Return keys/paths containing a list or tuple of h5py.VirtualSource objects."""
 
         def has_virtual_sources(value):
             if isinstance(value, h5py.VirtualSource):
@@ -309,7 +311,7 @@ class NXobject:
 
     @staticmethod
     def _get_data_urls(ddict) -> tuple:
-        """Return key / path containing a list or a tuple of silx.io.url.DataUrl"""
+        """Return keys/paths containing a list or tuple of silx.io.url.DataUrl objects."""
 
         def has_data_url(value):
             if isinstance(value, DataUrl):
@@ -335,8 +337,9 @@ class NXobject:
     @staticmethod
     def concatenate(nx_objects: tuple, node_name: str):
         """
-        concatenate a tuple of NXobject into a single NXobject
-        :param Iterable Nx-objects: nx object to concatenate
+        Concatenate a tuple of NXobjects into a single NXobject.
+
+        :param nx_objects: NXobjects to concatenate.
         :param node_name: name of the node to create. Parent must be handled manually for now.
         """
         raise NotImplementedError("Base class")
