@@ -18,13 +18,13 @@ from nxtomo.nxobject.utils.ObjectWithPixelSizeMixIn import _ObjectWithPixelSizeM
 from nxtomo.paths.nxtomo import get_paths as get_nexus_paths
 from nxtomo.utils import get_data, get_quantity
 
+_ureg = pint.get_application_registry()
+
 _logger = logging.getLogger(__name__)
 
 __all__ = [
     "NXsample",
 ]
-
-_ureg = pint.UnitRegistry()
 _meter = _ureg.meter
 _degree = _ureg.degree
 
