@@ -6,9 +6,9 @@ import logging
 from copy import deepcopy
 
 import h5py
+import pint
 
 # For unit conversion using pint
-import pint
 from silx.io.dictdump import nxtodict
 from silx.io.utils import open as hdf5_open
 from silx.utils.proxy import docstring
@@ -19,7 +19,7 @@ from nxtomo.utils.transformation import GravityTransformation, Transformation
 from nxtomo.utils.transformation import get_lr_flip as _get_lr_flip
 from nxtomo.utils.transformation import get_ud_flip as _get_ud_flip
 
-_ureg = pint.UnitRegistry()
+_ureg = pint.get_application_registry()
 
 _logger = logging.getLogger(__name__)
 
