@@ -15,8 +15,8 @@ from nxtomo.nxobject.nxdetector import (
     NXdetectorWithUnit,
 )
 from nxtomo.utils.transformation import (
+    DetXFlipTransformation,
     DetYFlipTransformation,
-    DetZFlipTransformation,
     Transformation,
     TransformationAxis,
 )
@@ -29,7 +29,7 @@ _degree = _ureg.degree
 
 
 def test_nx_detector():
-    """test creation and saving of an nxdetector"""
+    """Test creation and saving of an NXdetector."""
     nx_detector = NXdetector(expected_dim=(2, 3))
 
     # check data
@@ -60,15 +60,6 @@ def test_nx_detector():
         nx_detector.y_pixel_size = {}
     nx_detector.y_pixel_size = 2e-7 * _meter
 
-    # check x_flipped and y_flipped
-    with pytest.raises(TypeError):
-        nx_detector.x_flipped = 12
-    with pytest.raises(TypeError):
-        nx_detector.y_flipped = 12
-
-    nx_detector.x_flipped = True
-    nx_detector.y_flipped = False
-
     # check detector distance
     with pytest.raises(TypeError):
         nx_detector.distance = "test"
@@ -168,7 +159,7 @@ def test_nx_detector_with_unit():
 
 
 def test_nx_detector_with_virtual_source():
-    """Insure detector data can be write from Virtual sources"""
+    """Ensure detector data can be written from virtual sources."""
     cwd = os.getcwd()
     with tempfile.TemporaryDirectory() as tmp_folder:
         # create virtual dataset
@@ -222,7 +213,7 @@ def test_nx_detector_with_virtual_source():
 
 
 def test_nx_detector_with_local_urls():
-    """Insure detector data can be write from DataUrl linking to local dataset (in the same file)"""
+    """Ensure detector data can be written from DataUrl objects linking to local datasets (in the same file)."""
 
     cwd = os.getcwd()
     n_base_dataset = 3
@@ -275,7 +266,7 @@ def test_nx_detector_with_local_urls():
 
 
 def test_nx_detector_with_external_urls():
-    """Insure detector data can be write from DataUrl linking to external dataset"""
+    """Ensure detector data can be written from DataUrl objects linking to external datasets."""
     cwd = os.getcwd()
     with tempfile.TemporaryDirectory() as tmp_folder:
         # create virtual dataset
@@ -381,9 +372,8 @@ def test_load_detector_data(tmp_path, load_data_as, expected_type):
 
 def test_nxtransformations_with_nxdetector(tmp_path):
     """
-    test behavior of an Nxtransformations with an NXtomo
-    and coherence between lr_flip / ud_flip API (provided for convenience) and providing directly the
-    transformations
+    Test the behaviour of NXtransformations with an NXtomo and ensure coherence between the
+    ``lr_flip``/``ud_flip`` convenience API and providing transformations directly.
     """
 
     def build_detector():
@@ -399,13 +389,13 @@ def test_nxtransformations_with_nxdetector(tmp_path):
     # test having a left-right flip
     nx_detector_1.transformations.add_transformation(
         Transformation(
-            axis_name="rz",
+            axis_name="ry",
             value=180 * _degree,
             transformation_type="rotation",
-            vector=TransformationAxis.AXIS_Z,
+            vector=TransformationAxis.AXIS_Y,
         )
     )
-    nx_detector_2.x_flipped = True
+    nx_detector_2.set_transformation_from_lr_flipped(True)
 
     assert (
         nx_detector_1.transformations.to_nx_dict()
@@ -417,13 +407,13 @@ def test_nxtransformations_with_nxdetector(tmp_path):
     nx_detector_4 = build_detector()
     nx_detector_3.transformations.add_transformation(
         Transformation(
-            axis_name="ry",
+            axis_name="rx",
             value=180 * _degree,
             transformation_type="rotation",
-            vector=TransformationAxis.AXIS_Y,
+            vector=TransformationAxis.AXIS_X,
         )
     )
-    nx_detector_4.y_flipped = True
+    nx_detector_4.set_transformation_from_ud_flipped(True)
 
     assert (
         nx_detector_3.transformations.to_nx_dict()
@@ -434,6 +424,14 @@ def test_nxtransformations_with_nxdetector(tmp_path):
     nx_detector_5 = build_detector()
     nx_detector_6 = build_detector()
 
+    nx_detector_5.transformations.add_transformation(
+        Transformation(
+            axis_name="rx",
+            value=180 * _degree,
+            transformation_type="rotation",
+            vector=TransformationAxis.AXIS_X,
+        )
+    )
     nx_detector_5.transformations.add_transformation(
         Transformation(
             axis_name="ry",
@@ -442,16 +440,8 @@ def test_nxtransformations_with_nxdetector(tmp_path):
             vector=TransformationAxis.AXIS_Y,
         )
     )
-    nx_detector_5.transformations.add_transformation(
-        Transformation(
-            axis_name="rz",
-            value=180 * _degree,
-            transformation_type="rotation",
-            vector=TransformationAxis.AXIS_Z,
-        )
-    )
-    nx_detector_6.x_flipped = True
-    nx_detector_6.y_flipped = True
+    nx_detector_6.set_transformation_from_lr_flipped(True)
+    nx_detector_6.set_transformation_from_ud_flipped(True)
 
     assert (
         nx_detector_5.transformations.to_nx_dict()
@@ -460,15 +450,13 @@ def test_nxtransformations_with_nxdetector(tmp_path):
 
 
 def test_several_nxtransformations(tmp_path):
-    """
-    try loading NXtransformations
-    """
+    """Try loading multiple NXtransformations."""
     file_path = str(tmp_path / "test_transformations.nx")
     nx_detector = NXdetector(expected_dim=(2, 3))
     nx_detector.data = numpy.random.random(100 * 100 * 5).reshape(5, 100, 100)
     nx_detector.image_key_control = [1] * 5
     nx_detector.image_key_control = [ImageKey.PROJECTION] * 5
-    nx_detector.transformations.add_transformation(DetZFlipTransformation(flip=True))
+    nx_detector.transformations.add_transformation(DetYFlipTransformation(flip=True))
 
     nx_detector.save(file_path=file_path, data_path="detector", nexus_path_version=1.3)
 
@@ -482,7 +470,7 @@ def test_several_nxtransformations(tmp_path):
     )
     assert (
         len(load_det.transformations.transformations) == 2
-    )  # the DetZFlipTransformation + gravity
+    )  # the DetYFlipTransformation + gravity
 
     # test2: two transformations - one stored at the default location
     with h5py.File(file_path, mode="a") as h5f:
@@ -498,7 +486,7 @@ def test_several_nxtransformations(tmp_path):
     )
     assert (
         len(load_det.transformations.transformations) == 2
-    )  # the DetZFlipTransformation + gravity
+    )  # the DetYFlipTransformation + gravity
 
     # test3: two transformations - none at the default location
     with h5py.File(file_path, mode="a") as h5f:
@@ -527,34 +515,32 @@ def test_several_nxtransformations(tmp_path):
     )
     assert (
         len(load_det.transformations.transformations) == 2
-    )  # the DetZFlipTransformation + gravity
+    )  # the DetYFlipTransformation + gravity
 
 
 def test_detector_flips(tmp_path):
-    """
-    Make sure the 'deprecated' API 'x_flip' and 'y_flip' are working
-    """
+    """Ensure the deprecated `x_flip` and `y_flip` APIs still work."""
     # build some default detector
     nx_detector = NXdetector(expected_dim=(2, 3))
     nx_detector.data = numpy.random.random(100 * 100 * 5).reshape(5, 100, 100)
     nx_detector.image_key_control = [1] * 5
     nx_detector.image_key_control = [ImageKey.PROJECTION] * 5
 
-    nx_detector.y_flipped = True
+    nx_detector.set_transformation_from_ud_flipped(True)
     assert (
-        DetZFlipTransformation(flip=True)
+        DetYFlipTransformation(flip=True)
         not in nx_detector.transformations.transformations
     )
+    assert (
+        DetXFlipTransformation(flip=True) in nx_detector.transformations.transformations
+    )
+    nx_detector.set_transformation_from_lr_flipped(True)
     assert (
         DetYFlipTransformation(flip=True) in nx_detector.transformations.transformations
     )
-    nx_detector.x_flipped = True
+    nx_detector.set_transformation_from_lr_flipped(False)
     assert (
-        DetZFlipTransformation(flip=True) in nx_detector.transformations.transformations
-    )
-    nx_detector.x_flipped = False
-    assert (
-        DetZFlipTransformation(flip=True)
+        DetYFlipTransformation(flip=True)
         not in nx_detector.transformations.transformations
     )
 
@@ -569,7 +555,12 @@ def test_detector_flips(tmp_path):
         nexus_version=1.3,
     )
     assert len(loaded_nx_detector.transformations) == 3
-    assert loaded_nx_detector.x_flipped is False
-    for i in range(3):
-        print(f"{loaded_nx_detector.transformations.transformations[i]}\n")
-    assert loaded_nx_detector.y_flipped is True
+    assert (
+        DetYFlipTransformation(flip=True)
+        not in loaded_nx_detector.transformations.transformations
+    )
+
+    assert (
+        DetXFlipTransformation(flip=True)
+        in loaded_nx_detector.transformations.transformations
+    )
