@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import os
 from tempfile import TemporaryDirectory
 
@@ -9,7 +7,7 @@ from nxtomo.nxobject.nxobject import NXobject
 
 
 class test_nx_object:
-    """Tets API of the nx object"""
+    """Test API of the NXobject."""
 
     with pytest.raises(TypeError):
         NXobject(node_name=12)
