@@ -10,7 +10,7 @@ meter = ureg.meter
 
 
 def test_nx_sample():
-    """test creation and saving of an nxsource"""
+    """Test creation and saving of an NXsample."""
     nx_sample = NXsample()
     # check name
     with pytest.raises(TypeError):
@@ -58,34 +58,53 @@ def test_nx_sample():
     # test concatenation
     nx_sample_concat = NXsample.concatenate([nx_sample, nx_sample])
     assert nx_sample_concat.name == "my sample"
-    numpy.testing.assert_array_equal(
-        nx_sample_concat.rotation_angle,
+    expected_rotation = (
         numpy.concatenate(
             [
                 numpy.linspace(0, 180, 180, endpoint=False),
                 numpy.linspace(0, 180, 180, endpoint=False),
             ]
-        ),
+        )
+        * degree
     )
-
     numpy.testing.assert_array_equal(
-        nx_sample_concat.x_translation,
+        nx_sample_concat.rotation_angle.magnitude,
+        expected_rotation.magnitude,
+    )
+    assert str(nx_sample_concat.rotation_angle.units) == str(expected_rotation.units)
+
+    expected_x_translation = (
         numpy.concatenate(
             [
                 numpy.linspace(0, 180, 180, endpoint=False),
                 numpy.linspace(0, 180, 180, endpoint=False),
             ]
-        ),
+        )
+        * meter
+    )
+    numpy.testing.assert_array_equal(
+        nx_sample_concat.x_translation.magnitude,
+        expected_x_translation.magnitude,
+    )
+    assert str(nx_sample_concat.x_translation.units) == str(
+        expected_x_translation.units
     )
 
-    numpy.testing.assert_array_equal(
-        nx_sample_concat.y_translation,
+    expected_y_translation = (
         numpy.concatenate(
             [
                 numpy.asarray([0.0] * 180),
                 numpy.asarray([0.0] * 180),
             ]
-        ),
+        )
+        * meter
+    )
+    numpy.testing.assert_array_equal(
+        nx_sample_concat.y_translation.magnitude,
+        expected_y_translation.magnitude,
+    )
+    assert str(nx_sample_concat.y_translation.units) == str(
+        expected_y_translation.units
     )
 
     assert nx_sample_concat.z_translation is None
