@@ -1,3 +1,3 @@
-"""module with some MixIn classes"""
+"""Module providing NXobject mixin classes."""
 
 from .concatenate import concatenate  # noqa F401
