@@ -1,22 +1,22 @@
 """
-utils for NXobject
+Utility helpers for NXobject concatenation.
 """
 
-from typing import Iterable, Optional, Tuple
-
 import numpy
 import pint
 
 from nxtomo.nxobject.nxobject import NXobject
 
 
-def concatenate(nx_objects: Iterable, **kwargs) -> NXobject:
+def concatenate(
+    nx_objects: list[NXobject] | tuple[NXobject, ...], **kwargs
+) -> NXobject:
     """
-    concatenate a list of NXobjects
+    Concatenate a list of NXobjects.
 
-    :param Iterable nx_objects: objects to be concatenated. They are expected to be of the same type.
+    :param list | tuple nx_objects: objects to be concatenated. They are expected to be of the same type. Accepts list, or tuple.
     :param kwargs: extra parameters
-    :return: concatenated object. Of the same type of 'nx_objects'
+    :return: concatenated object, of the same type as ``nx_objects``.
     :rtype: :class:`~nxtomo.nxobject.nxobject.NXobject`
     """
     if len(nx_objects) == 0:
@@ -28,10 +28,10 @@ def concatenate(nx_objects: Iterable, **kwargs) -> NXobject:
 
 
 def concatenate_pint_quantities(
-    quantities: Tuple[pint.Quantity, ...],
-) -> Optional[pint.Quantity]:
+    quantities: tuple[pint.Quantity, ...],
+) -> pint.Quantity | None:
     """
-    Helper function to concatenate pint quantities while ensuring unit consistency
+    Helper function to concatenate pint quantities while ensuring unit consistency.
     """
     if len(quantities) == 0:
         return None
