@@ -6,8 +6,7 @@ from functools import wraps
 
 import pint
 
-# Initialize the unit registry
-ureg = pint.UnitRegistry()
+_ureg = pint.get_application_registry()
 
 
 def check_dimensionality(expected_dimension: str, allow_none: bool = True):
@@ -20,7 +19,7 @@ def check_dimensionality(expected_dimension: str, allow_none: bool = True):
     def check_parameter(parameter, parameter_name: str, allow_none: bool):
         # Check if the value is a pint.Quantity and has the expected dimensionality
         if isinstance(parameter, pint.Quantity):
-            if parameter.dimensionality != ureg.get_dimensionality(expected_dimension):
+            if parameter.dimensionality != _ureg.get_dimensionality(expected_dimension):
                 raise TypeError(
                     f"{parameter_name}: expected dimensionality {expected_dimension}, but got {parameter.dimensionality}."
                 )
