@@ -1,4 +1,4 @@
-"""nexus path used to define a `NXdetector <https://manual.nexusformat.org/classes/base_classes/NXdetector.html>`_"""
+"""NeXus paths used to define an `NXdetector <https://manual.nexusformat.org/classes/base_classes/NXdetector.html>`_."""
 
 
 class NEXUS_DETECTOR_PATH:
