@@ -1,4 +1,4 @@
-"""nexus path used to define a `NXinstrument <https://manual.nexusformat.org/classes/base_classes/NXinstrument.html>`_"""
+"""NeXus paths used to define an `NXinstrument <https://manual.nexusformat.org/classes/base_classes/NXinstrument.html>`_."""
 
 
 class NEXUS_INSTRUMENT_PATH:
