@@ -1,4 +1,4 @@
-"""nexus path used to define a `NXmonitor <https://manual.nexusformat.org/classes/base_classes/NXmonitor.html>`_"""
+"""NeXus paths used to define an `NXmonitor <https://manual.nexusformat.org/classes/base_classes/NXmonitor.html>`_."""
 
 
 class NEXUS_MONITOR_PATH:
