@@ -1,4 +1,4 @@
-"""nexus path used to define a `NXsample <https://manual.nexusformat.org/classes/base_classes/NXsample.html>`_"""
+"""NeXus paths used to define an `NXsample <https://manual.nexusformat.org/classes/base_classes/NXsample.html>`_."""
 
 from . import nxtransformations
 
