@@ -1,4 +1,4 @@
-"""nexus path used to define a `NXsource <https://manual.nexusformat.org/classes/base_classes/NXsource.html>`_"""
+"""NeXus paths used to define an `NXsource <https://manual.nexusformat.org/classes/base_classes/NXsource.html>`_."""
 
 
 class NEXUS_SOURCE_PATH:
