@@ -1,6 +1,4 @@
-"""nexus path used to define a `NXtomo <https://manual.nexusformat.org/classes/base_classes/NXtomo.html>`_"""
-
-from __future__ import annotations
+"""NeXus paths used to define an `NXtomo <https://manual.nexusformat.org/classes/base_classes/NXtomo.html>`_."""
 
 import logging
 
@@ -18,7 +16,7 @@ from nxtomo.utils.io import deprecated
 _logger = logging.getLogger(__name__)
 
 
-LATEST_VERSION = 1.5
+LATEST_VERSION = 2.0
 
 
 class NXtomo_PATH:
@@ -179,28 +177,6 @@ class NXtomo_PATH:
             ]
         )
 
-    @property
-    @deprecated(replacement="X_PIXEL_SIZE_PATH", since_version="1.1.0")
-    def X_PIXEL_MAG_SIZE_PATH(self) -> str:
-        return "/".join(
-            [
-                self.INSTRUMENT_PATH,
-                self.nx_instrument_paths.DETECTOR_PATH,
-                self.nx_detector_paths.X_PIXEL_SIZE_MAGNIFIED,
-            ]
-        )
-
-    @property
-    @deprecated(replacement="Y_PIXEL_SIZE_PATH", since_version="1.1.0")
-    def Y_PIXEL_MAG_SIZE_PATH(self) -> str:
-        return "/".join(
-            [
-                self.INSTRUMENT_PATH,
-                self.nx_instrument_paths.DETECTOR_PATH,
-                self.nx_detector_paths.Y_PIXEL_SIZE_MAGNIFIED,
-            ]
-        )
-
     @property
     @deprecated(replacement="SAMPLE_DETECTOR_DISTANCE_PATH", since_version="2.0")
     def DISTANCE_PATH(self) -> str:
@@ -245,21 +221,6 @@ class NXtomo_PATH:
             ]
         )
 
-    @property
-    @deprecated(
-        replacement="nexuspaths.INSTRUMENT_PATH/nexuspath.nx_instrument_paths.DETECTOR_PATH/nexuspaths.detector_paths.Y_ROTATION_AXIS_PIXEL_POSITION",
-        reason="typo",
-        since_version="0.8.0",
-    )
-    def ESTIMATED_COR_FRM_MOTOR_PATH(self) -> str:
-        return "/".join(
-            [
-                self.INSTRUMENT_PATH,
-                self.nx_instrument_paths.DETECTOR_PATH,
-                self.nx_detector_paths.Y_ROTATION_AXIS_PIXEL_POSITION,
-            ]
-        )
-
     @property
     def TOMO_N_SCAN(self) -> str:
         return "/".join(
@@ -282,22 +243,10 @@ class NXtomo_PATH:
     def END_TIME_PATH(self) -> str:
         return "end_time"
 
-    @property
-    @deprecated(replacement="END_TIME_PATH", reason="typo", since_version="0.8.0")
-    def END_TIME_START(self) -> str:
-        return self.END_TIME_PATH
-
     @property
     def INTENSITY_MONITOR_PATH(self) -> str:
         return "diode/data"
 
-    @property
-    @deprecated(
-        replacement="", reason="will be removed. Not used", since_version="0.8.0"
-    )
-    def EPSILON_ROT_ANGLE(self) -> float:
-        return 0.02
-
     @property
     def SOURCE_NAME(self) -> str | None:
         return None
@@ -518,7 +467,16 @@ class NXtomo_PATH_v_1_5(NXtomo_PATH_v_1_4):
 nx_tomo_path_v_1_5 = NXtomo_PATH_v_1_5()
 
 
-nx_tomo_path_latest = nx_tomo_path_v_1_5
+class NXtomo_PATH_v_2_0(NXtomo_PATH_v_1_5):
+    # Warning: there was no modification on the path but
+    # this is a milestone when moving to McStas
+    VERSION = 2.0
+
+
+nx_tomo_path_v_2_0 = NXtomo_PATH_v_2_0()
+
+
+nx_tomo_path_latest = nx_tomo_path_v_2_0
 
 
 def get_paths(version: float | None) -> NXtomo_PATH:
@@ -539,6 +497,7 @@ def get_paths(version: float | None) -> NXtomo_PATH:
         1.3: nx_tomo_path_v_1_3,
         1.4: nx_tomo_path_v_1_4,
         1.5: nx_tomo_path_v_1_5,
+        2.0: nx_tomo_path_v_2_0,
     }
     if version not in versions_dict:
         if int(version) == 1:
