@@ -1,4 +1,4 @@
-"""nexus path used to define a `NXtransformations <https://manual.nexusformat.org/classes/base_classes/NXtransformations.html>`_"""
+"""NeXus paths used to define an `NXtransformations <https://manual.nexusformat.org/classes/base_classes/NXtransformations.html>`_."""
 
 
 class NEXUS_TRANSFORMATIONS_PATH:
