@@ -22,7 +22,7 @@
 #
 #############################################################################
 
-"""test compatibility with previously existing NexusPath classes"""
+"""Test compatibility with previously existing NexusPath classes."""
 
 
 __authors__ = ["H.Payno"]
@@ -38,9 +38,9 @@ from nxtomo.paths.nxtomo import nx_tomo_path_latest
 
 # classes which were previously defining path to save data as NXtomo from tomoscan.esrf.scan.nxtomoscan.py file
 class _NEXUS_PATHS:
-    """Register path to NXtomo
-    The raw data are the one of the initial version.
-    If the value is None then the path was not existing originally.
+    """Register paths for NXtomo.
+    The raw data are those of the initial version.
+    If the value is None then the path did not exist originally.
     """
 
     PROJ_PATH = "instrument/detector/data"
@@ -95,8 +95,6 @@ class _NEXUS_PATHS:
 
     INTENSITY_MONITOR_PATH = "diode/data"
 
-    EPSILON_ROT_ANGLE = 0.02
-
     SOURCE_NAME = None
 
     SOURCE_TYPE = None
@@ -134,7 +132,7 @@ _class_to_compare_versions = {
 
 @pytest.mark.parametrize("path_version", (1.0, 1.1))
 def test_compare_result(path_version):
-    """insure the new way of providing nexus path does not break the previous API or values"""
+    """Ensure the new way of providing NeXus paths does not break the previous API or values."""
     old_class, new_class = _class_to_compare_versions[path_version]
     assert old_class.PROJ_PATH == new_class.PROJ_PATH
     assert old_class.SCAN_META_PATH == new_class.SCAN_META_PATH
@@ -151,18 +149,14 @@ def test_compare_result(path_version):
     assert old_class.IMG_KEY_CONTROL_PATH == new_class.IMG_KEY_CONTROL_PATH
     assert old_class.X_PIXEL_SIZE_PATH == new_class.X_PIXEL_SIZE_PATH
     assert old_class.Y_PIXEL_SIZE_PATH == new_class.Y_PIXEL_SIZE_PATH
-    assert old_class.X_PIXEL_MAG_SIZE_PATH == new_class.X_PIXEL_MAG_SIZE_PATH
-    assert old_class.Y_PIXEL_MAG_SIZE_PATH == new_class.Y_PIXEL_MAG_SIZE_PATH
     assert old_class.DISTANCE_PATH == new_class.DISTANCE_PATH
     assert old_class.FOV_PATH == new_class.FOV_PATH
     assert old_class.EXPOSURE_TIME_PATH == new_class.EXPOSURE_TIME_PATH
     assert old_class.TOMO_N_SCAN == new_class.TOMO_N_SCAN
     assert old_class.ENERGY_PATH == new_class.ENERGY_PATH
     assert old_class.START_TIME_PATH == new_class.START_TIME_PATH
-    assert old_class.END_TIME_START == new_class.END_TIME_START
     assert old_class.END_TIME_PATH == new_class.END_TIME_PATH
     assert old_class.INTENSITY_MONITOR_PATH == new_class.INTENSITY_MONITOR_PATH
-    assert old_class.EPSILON_ROT_ANGLE == new_class.EPSILON_ROT_ANGLE
     assert old_class.SOURCE_NAME == new_class.SOURCE_NAME
     assert old_class.SOURCE_TYPE == new_class.SOURCE_TYPE
     assert old_class.INSTRUMENT_NAME == new_class.INSTRUMENT_NAME
@@ -174,4 +168,4 @@ def test_unknow_nexus_path_version():
     with pytest.raises(ValueError):
         assert new_get_paths(-1.0) is None
     with pytest.raises(ValueError):
-        assert new_get_paths(2.0) is None
+        assert new_get_paths(999.0) is None
