@@ -1,9 +1,7 @@
 """
-module to split a NXtomo into several
+Utilities to split an NXtomo into several parts.
 """
 
-from __future__ import annotations
-
 import copy
 import logging
 
@@ -27,13 +25,13 @@ __all__ = [
 class NXtomoSplitter:
     def __init__(self, nx_tomo: NXtomo) -> None:
         """
-        Class to split an Nxtomo into a subset of NXtomo
+        Helper class used to split an NXtomo into smaller NXtomo subsets.
 
-        This will also keep up to date rotation_angle, image_key, x_translation... datasets.
-        In order to start the processing it requires a correctly formed NXtomo (same number of image_key, rotation_angle...)
-        This is required for the pcotomo acquisition.
+        This also keeps datasets such as `rotation_angle`, `image_key`, and `x_translation`
+        consistent with the split. The provided NXtomo must be well formed (same length for
+        `image_key`, `rotation_angle`, and related arrays). This is required for PCOTOMO acquisitions.
 
-        :param nx_tomo: nx_tomo to be splitted
+        :param nx_tomo: NXtomo to be split.
         """
         if not isinstance(nx_tomo, NXtomo):
             raise TypeError(
@@ -44,9 +42,7 @@ class NXtomoSplitter:
     @property
     def nx_tomo(self) -> NXtomo:
         """
-        nx_tomo to be splitted
-
-        :param nx_tomo: nx_tomo to be splitted
+        NXtomo instance to be split.
         """
         return self._nx_tomo
 
@@ -57,18 +53,18 @@ class NXtomoSplitter:
         tomo_n: int | None = None,
     ) -> tuple:
         """
-        split the given slice into NXtomo containing tomo_n projections or into nb_part.
-        Only the 'data_slice' section will be split. Other parts stays untouched.
+        Split the given slice into NXtomo objects containing `tomo_n` projections or into `nb_part` subsets.
+        Only the `data_slice` section is split; other parts remain untouched.
 
-        Behavior according to 'nb_part' and 'tomo_n' is the following:
+        Behaviour according to `nb_part` and `tomo_n`:
 
-        * if **only** 'nb_part' is provided it will split the NXtomo into 'nb_part' NXtomos
-        * if **only** 'tomo_n' is provided it will take the first 'tomo_n' projections to create an NXtomo, then the next 'tomo_n'...
-        * if both are provided then it will use the 'tomo_n' parameter (since version 1.3). As it will work better in case of missing frames in the acquisition.
+        * If **only** `nb_part` is provided, split the NXtomo into that many NXtomos.
+        * If **only** `tomo_n` is provided, take the first `tomo_n` projections to create an NXtomo, then the next `tomo_n`, and so on.
+        * If both are provided, use the `tomo_n` parameter (since version 1.3). This works better when frames are missing.
 
-        :param nb_part: in how many contiguous dataset the instrument.detector.data must be splitted.
-        :param tomo_n: expected number of projection per NXtomo
-        :raises: ValueError if the number of frame, image_key, x_translation... is incoherent.
+        :param nb_part: how many contiguous subsets the detector data must be split into.
+        :param tomo_n: expected number of projections per NXtomo.
+        :raises ValueError: if the number of frames, image_key entries, translations, etc., is inconsistent.
         """
         if nb_part is not None and not isinstance(
             nb_part, (int, type(None), numpy.integer)
@@ -110,23 +106,18 @@ class NXtomoSplitter:
 
     def _split_from_tomo_n(self, tomo_n: int, data_slice: slice) -> tuple[NXtomo]:
         parts = []
-        n_slices_remaining = data_slice.stop - data_slice.start - 1
-        current_slice = data_slice
-        i_part = 0
-        while n_slices_remaining > 0:
-            new_slice_size = tomo_n
+        total_length = data_slice.stop - data_slice.start
+        if total_length <= 0:
+            return tuple(parts)
+
+        for offset in range(0, total_length, tomo_n):
             new_slice = slice(
-                current_slice.start + new_slice_size * i_part,
-                min(
-                    current_slice.start + new_slice_size * (i_part + 1),
-                    current_slice.stop,
-                ),
+                data_slice.start + offset,
+                min(data_slice.start + offset + tomo_n, data_slice.stop),
                 1,
             )
             nx_tomo_part = self.replace(old_slice=data_slice, new_slice=new_slice)
             parts.append(nx_tomo_part)
-            n_slices_remaining -= tomo_n
-            i_part += 1
         return tuple(parts)
 
     def _split_from_nb_part(self, nb_part, data_slice: slice) -> tuple[NXtomo]:
@@ -145,7 +136,7 @@ class NXtomoSplitter:
 
     def replace(self, old_slice: slice, new_slice: slice) -> NXtomo:
         """
-        replace a section of the NXtomo instrument.detector.data by a subsection of it
+        Replace a section of ``instrument.detector.data`` with a subsection of itself.
         """
         if not isinstance(old_slice, slice):
             raise TypeError("old_slice is expected to be a slice")
@@ -271,7 +262,7 @@ class NXtomoSplitter:
 
     def _get_detector_data_sub_section(self, section: slice) -> tuple:
         """
-        return a tuple of DataUrl or h5py.VirtualSource fitting the slice requested
+        Return a tuple of DataUrl or h5py.VirtualSource objects matching the requested slice.
         """
         det_data = self.nx_tomo.instrument.detector.data
         res = []
@@ -299,7 +290,7 @@ class NXtomoSplitter:
                 raise ValueError(f"virtualSource: {elmt} is not 2D or 3D")
 
         def construct_slices_elmt_list() -> dict:
-            "create a dictionary with slice as key and DataUrl or h5py.VirtualSource as value"
+            """Create a dictionary with slices as keys and DataUrl or h5py.VirtualSource values."""
             slices_elmts = []
 
             current_index = 0
@@ -311,7 +302,7 @@ class NXtomoSplitter:
             return slices_elmts
 
         def intersect(slice_1, slice_2):
-            """check if the two slices intersect"""
+            """Check whether the two slices intersect."""
             assert isinstance(slice_1, slice) and slice_1.step == 1
             assert isinstance(slice_2, slice) and slice_2.step == 1
             return slice_1.start < slice_2.stop and slice_1.stop > slice_2.start
@@ -319,8 +310,8 @@ class NXtomoSplitter:
         def select(
             elmt: h5py.VirtualSource | DataUrl, region: slice
         ) -> h5py.VirtualSource | DataUrl:
-            """select a region on the elmt.
-            Can return at most the elmt itself or a region of it"""
+            """Select a region on the element.
+            Can return at most the element itself or a sub-region of it."""
             elmt_n_frame = get_elmt_nb_frame(elmt)
             assert elmt_n_frame != 0
             clamp_region = slice(
