@@ -1,9 +1,7 @@
 """
-module to append frame to an hdf5 dataset (that can be virtual)
+Utilities to append frames to an HDF5 dataset (including virtual datasets).
 """
 
-from __future__ import annotations
-
 import os
 
 import h5py
@@ -37,13 +35,13 @@ class FrameAppender:
         logger=None,
     ):
         """
-        Class to insert 2D frame(s) to an existing dataset
+        Insert 2D frame(s) into an existing dataset.
 
-        :param data: data to append
-        :param file_path: file path of the HDF5 dataset to extend
-        :param data_path: file data_path of the HDF5 dataset to extend
-        :param where: can be 'start' or 'end' to know if we should append frame at the beginning or at the end
-        :param logger: optional logger to handle logs
+        :param data: data to append.
+        :param file_path: file path of the HDF5 dataset to extend.
+        :param data_path: data path of the HDF5 dataset to extend.
+        :param where: ``"start"`` or ``"end"`` to indicate whether frames are prepended or appended.
+        :param logger: optional logger used to handle logs.
         """
         if where not in ("start", "end"):
             raise ValueError("`where` should be `start` or `end`")
@@ -63,7 +61,7 @@ class FrameAppender:
 
     def process(self) -> None:
         """
-        main function. Will start the insertion of frame(s)
+        Entry point that inserts the frame(s).
         """
         with HDF5File(self.file_path, mode="a") as h5s:
             if self.data_path in h5s:
@@ -228,12 +226,9 @@ class FrameAppender:
 
     def _add_to_existing_none_virtual_dataset(self, h5s):
         """
-        for now when we want to add data *to a none virtual dataset*
-        we always duplicate data if provided from a DataUrl.
-        We could create a virtual dataset as well but seems to complicated for
-        a use case that we don't really have at the moment.
+        Append data to a non-virtual dataset by duplicating the provided data.
 
-        :param h5s:
+        :param h5s: HDF5 file handle.
         """
         if self.logger is not None:
             self.logger.debug("Update dataset: {entry}@{file_path}")
@@ -292,9 +287,10 @@ class FrameAppender:
 
     def _create_new_dataset(self, h5s):
         """
-        needs to create a new dataset. In this case the policy is:
-           - if a DataUrl is provided then we create a virtual dataset
-           - if a numpy array is provided then we create a 'standard' dataset
+        Create a new dataset following these rules:
+
+           - if a DataUrl is provided, create a virtual dataset;
+           - if a NumPy array is provided, create a standard dataset.
         """
 
         if isinstance(self.data, DataUrl):
@@ -343,11 +339,9 @@ class FrameAppender:
 
     @staticmethod
     def _recreate_vs(vs_info, vds_file):
-        """Simple util to retrieve a h5py.VirtualSource from virtual source
-        information.
+        """Utility to rebuild an h5py.VirtualSource from stored virtual-source information.
 
-        to understand clearly this function you might first have a look at
-        the use case exposed in issue:
+        For additional context, see the use case described in issue
         https://gitlab.esrf.fr/tomotools/nxtomomill/-/issues/40
         """
         with cwd_context(os.path.dirname(vds_file)):
