@@ -1,4 +1,4 @@
-"""io utils"""
+"""I/O utilities."""
 
 import contextlib
 import functools
@@ -37,7 +37,7 @@ class _BaseReader(contextlib.AbstractContextManager):
 
 
 class EntryReader(_BaseReader):
-    """Context manager used to read a bliss node"""
+    """Context manager used to read a BLISS node."""
 
     def __enter__(self):
         self._file_handler = hdf5_open(filename=self._url.file_path())
@@ -55,7 +55,7 @@ class EntryReader(_BaseReader):
 
 
 class DatasetReader(_BaseReader):
-    """Context manager used to read a bliss node"""
+    """Context manager used to read a BLISS node."""
 
     def __enter__(self):
         self._file_handler = hdf5_open(filename=self._url.file_path())
@@ -82,21 +82,16 @@ def deprecated_warning(
     skip_backtrace_count=0,
 ):
     """
-    Function to log a deprecation warning
+    Log a deprecation warning.
 
-    :param type_: Nature of the object to be deprecated:
-        "Module", "Function", "Class" ...
+    :param type_: Nature of the object to be deprecated,
+        e.g. "Module", "Function", "Class".
     :param name: Object name.
-    :param reason: Reason for deprecating this function
-        (e.g. "feature no longer provided",
-    :param replacement: Name of replacement function (if the reason for
-        deprecating was to rename the function)
-    :param since_version: First *silx* version for which the function was
-        deprecated (e.g. "0.5.0").
-    :param only_once: If true, the deprecation warning will only be
-        generated one time for each different call locations. Default is true.
-    :param skip_backtrace_count: Amount of last backtrace to ignore when
-        logging the backtrace
+    :param reason: Reason for deprecating this object (e.g. "feature no longer provided").
+    :param replacement: Name of the replacement function (when the deprecation renames the function).
+    :param since_version: First *silx* version for which the function was deprecated (e.g. "0.5.0").
+    :param only_once: If True, the deprecation warning is generated only once for each call site. Default is True.
+    :param skip_backtrace_count: Number of trailing stack frames to ignore when logging the backtrace.
     """
     if not depreclog.isEnabledFor(logging.WARNING):
         # Avoid computation when it is not logged
@@ -132,18 +127,13 @@ def deprecated(
     skip_backtrace_count=1,
 ):
     """
-    Decorator that deprecates the use of a function
+    Decorator that deprecates the use of a function.
 
-    :param str reason: Reason for deprecating this function
-        (e.g. "feature no longer provided",
-    :param str replacement: Name of replacement function (if the reason for
-        deprecating was to rename the function)
-    :param str since_version: First *silx* version for which the function was
-        deprecated (e.g. "0.5.0").
-    :param bool only_once: If true, the deprecation warning will only be
-        generated one time. Default is true.
-    :param int skip_backtrace_count: Amount of last backtrace to ignore when
-        logging the backtrace
+    :param str reason: Reason for deprecating this function (e.g. "feature no longer provided").
+    :param str replacement: Name of the replacement function (when the deprecation renames the function).
+    :param str since_version: First *silx* version for which the function was deprecated (e.g. "0.5.0").
+    :param bool only_once: If True, the deprecation warning is generated only once. Default is True.
+    :param int skip_backtrace_count: Number of trailing stack frames to ignore when logging the backtrace.
     """
 
     def decorator(func):
@@ -169,7 +159,7 @@ def deprecated(
 
 @contextmanager
 def ignore_deprecation_warning():
-    """filter logs from 'nxtomo.DEPRECATION'"""
+    """Filter logs from 'nxtomo.DEPRECATION'."""
 
     def filter(record):
         return record.name != depreclog.name
