@@ -4,6 +4,7 @@ import pytest
 
 from nxtomo.paths.nxtransformations import NEXUS_TRANSFORMATIONS_PATH
 from nxtomo.utils.transformation import (
+    DetXFlipTransformation,
     DetYFlipTransformation,
     DetZFlipTransformation,
     GravityTransformation,
@@ -85,6 +86,7 @@ def test_Transformation():
 
 def test_helpers():
     """simple test on some helper class / function"""
+    DetXFlipTransformation(flip=True)
     DetYFlipTransformation(flip=True)
     DetZFlipTransformation(flip=True)
 
@@ -97,38 +99,38 @@ def test_get_lr_flip() -> tuple:
         axis_name="rad_rot",
         transformation_type="rotation",
         value=numpy.pi * _ureg.radian,
-        vector=TransformationAxis.AXIS_Z,
+        vector=TransformationAxis.AXIS_Y,
     )
-    assert trans_as_rad == DetZFlipTransformation(flip=True)
+    assert trans_as_rad == DetYFlipTransformation(flip=True)
     transformations = (
-        DetZFlipTransformation(flip=True),
+        DetYFlipTransformation(flip=True),
         Transformation(
             axis_name="toto",
             transformation_type="rotation",
             value=-180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Z,
+            vector=TransformationAxis.AXIS_Y,
         ),
         Transformation(
             axis_name="other",
             transformation_type="rotation",
             value=70 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Z,
+            vector=TransformationAxis.AXIS_Y,
         ),
         trans_as_rad,
         Transformation(
             axis_name="other2",
             transformation_type="rotation",
             value=180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Y,
+            vector=TransformationAxis.AXIS_X,
         ),
     )
     assert get_lr_flip(transformations=transformations) == (
-        DetZFlipTransformation(flip=True),
+        DetYFlipTransformation(flip=True),
         Transformation(
             axis_name="toto",
             transformation_type="rotation",
             value=-180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Z,
+            vector=TransformationAxis.AXIS_Y,
         ),
         trans_as_rad,
     )
@@ -143,36 +145,36 @@ def test_get_ud_flip() -> tuple:
             axis_name="other",
             transformation_type="rotation",
             value=70 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Z,
+            vector=TransformationAxis.AXIS_Y,
         ),
         Transformation(
             axis_name="toto",
             transformation_type="rotation",
             value=-180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Y,
+            vector=TransformationAxis.AXIS_X,
         ),
-        DetYFlipTransformation(flip=True),
+        DetXFlipTransformation(flip=True),
         Transformation(
             axis_name="other2",
             transformation_type="rotation",
             value=180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Y,
+            vector=TransformationAxis.AXIS_X,
         ),
-        DetZFlipTransformation(flip=True),
+        DetYFlipTransformation(flip=True),
     )
     assert get_ud_flip(transformations=transformations) == (
         Transformation(
             axis_name="toto",
             transformation_type="rotation",
             value=-180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Y,
+            vector=TransformationAxis.AXIS_X,
         ),
-        DetYFlipTransformation(flip=True),
+        DetXFlipTransformation(flip=True),
         Transformation(
             axis_name="other2",
             transformation_type="rotation",
             value=180 * _ureg.degree,
-            vector=TransformationAxis.AXIS_Y,
+            vector=TransformationAxis.AXIS_X,
         ),
     )
 
