@@ -6,8 +6,8 @@ import numpy
 import pint
 from silx.utils.enum import Enum as _Enum
 
-# Create a pint unit registry
-_ureg = pint.UnitRegistry()
+_ureg = pint.get_application_registry()
+
 _degree = _ureg.degree
 _meter = _ureg.meter
 _radian = _ureg.radian
